@@ -24,7 +24,7 @@ class DetailResults(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 该字段用于返回检测结果所对应的全部恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
         :param Suggestion: 该字段用于返回对应当前标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
@@ -45,6 +45,9 @@ class DetailResults(AbstractModel):
         :param LibName: 该字段**仅当Label为Custom：自定义关键词时该参数有效**,用于返回自定义库的名称,以方便自定义库管理和配置。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LibName: str
+        :param SubLabel: 该字段用于返回当前标签（Label）下的二级标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         """
         self.Label = None
         self.Suggestion = None
@@ -53,6 +56,7 @@ class DetailResults(AbstractModel):
         self.LibType = None
         self.LibId = None
         self.LibName = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -63,6 +67,7 @@ class DetailResults(AbstractModel):
         self.LibType = params.get("LibType")
         self.LibId = params.get("LibId")
         self.LibName = params.get("LibName")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -78,7 +83,7 @@ class Device(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param IP: 该字段表示业务用户对应设备的IP地址。<br>
 备注:目前仅支持IPv4地址记录，不支持IPv6地址记录。
         :type IP: str
@@ -128,7 +133,7 @@ class RiskDetails(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Label: 该字段用于返回账号信息检测对应的风险类别，取值为：**RiskAccount**（账号存在风险）、**RiskIP**（IP地址存在风险）、**RiskIMEI**（移动设备识别码存在风险）。
         :type Label: str
         :param Level: 该字段用于返回账号信息检测对应的风险等级，取值为：**1**（疑似存在风险）和**2**（存在恶意风险）。
@@ -156,8 +161,8 @@ class TextModerationRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param Content: 文本内容Base64编码，限制原文长度不能超过10000个unicode字符
+        r"""
+        :param Content: 该字段表示待检测对象的文本内容，长度不能超过10000（按unicode编码计算）
         :type Content: str
         :param BizType: 该字段表示策略的具体编号，用于接口调度，在内容安全控制台中可配置。若不传入Biztype参数（留空），则代表采用默认的识别策略；传入则会在审核时根据业务场景采取不同的审核策略。<br>备注：Biztype仅为数字、字母与下划线的组合，长度为3-32个字符；不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype
         :type BizType: str
@@ -200,7 +205,7 @@ class TextModerationResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BizType: 该字段用于返回请求参数中的BizType参数
         :type BizType: str
         :param Label: 该字段用于返回检测结果（DetailResults）中所对应的**优先级最高的恶意标签**，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型
@@ -224,6 +229,9 @@ class TextModerationResponse(AbstractModel):
         :param DataId: 该字段用于返回检测对象对应请求参数中的DataId，与输入的DataId字段中的内容对应
 注意：此字段可能返回 null，表示取不到有效值。
         :type DataId: str
+        :param SubLabel: 该字段用于返回当前标签（Label）下的二级标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SubLabel: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -236,6 +244,7 @@ class TextModerationResponse(AbstractModel):
         self.RiskDetails = None
         self.Extra = None
         self.DataId = None
+        self.SubLabel = None
         self.RequestId = None
 
 
@@ -259,6 +268,7 @@ class TextModerationResponse(AbstractModel):
                 self.RiskDetails.append(obj)
         self.Extra = params.get("Extra")
         self.DataId = params.get("DataId")
+        self.SubLabel = params.get("SubLabel")
         self.RequestId = params.get("RequestId")
 
 
@@ -268,7 +278,7 @@ class User(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 该字段表示业务用户ID,填写后，系统可根据账号过往违规历史优化审核结果判定，有利于存在可疑违规风险时的辅助判断。<br>
 备注：该字段可传入微信openid、QQopenid、字符串等账号信息，与账号类别参数（AccountType）配合使用可确定唯一账号。
         :type UserId: str
